##  Managing Diagram Templates
As your template list grows, use the management tools to quickly find and work with specific diagram templates.
  * Search and filter by template name, owner, permissions, creation or modification date, and diagram type.
  * Sort templates, for example, by name or date, to bring the most relevant ones to the top.
  * Switch between grid view (visual browsing) and list view (tabular details) depending on how you want to work with templates.


![Diagram templates page showing search, filter, and sort options above template cards.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiocd9fe7691dd949dfa2d71a65041d9ac2_LowRes.png)
Sorting and Filtering Templates
